
/*
	GoToSocial
	Copyright (C) GoToSocial Authors admin@gotosocial.org
	SPDX-License-Identifier: AGPL-3.0-or-later

	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU Affero General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU Affero General Public License for more details.

	You should have received a copy of the GNU Affero General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

/*
	Render instance title + image
	a bit bigger on index page.

	Overrides the css from page.css.
*/

.page-header > a > h1 {
			font-size: 2rem;
			line-height: 2rem;
		}

.page-header > a img,
		.page-header > a picture {
			align-self: center;
			max-height: 6rem;
		}

/*
	Reuse about styling, but rework it
	to separate sections a bit more.
*/

.about {
	display: flex;
	flex-direction: column;
	gap: 2rem;
	padding: 0;
	
	background: initial;
	box-shadow: initial;
	border: initial;
	border-radius: initial;
}

.about .about-section {
		padding: 2rem;
		background: var(--bg-accent);
		box-shadow: var(--boxshadow);
		border: var(--boxshadow-border);
		border-radius: var(--br);
	}

.what-is-this .about-section-contents .activitypub-logo-wrapper {
	display: flex;
	flex-direction: column;
	max-width: -moz-fit-content;
	max-width: fit-content;
	gap: 0.5rem;
}

.what-is-this .about-section-contents .activitypub-logo-wrapper .activitypub-logo {
		background: var(--fg);
	}

/* light mode */

@media (prefers-color-scheme: light) {

.what-is-this .about-section-contents .activitypub-logo-wrapper .activitypub-logo {
			background: none;
	}
		}

.what-is-this .about-section-contents .activitypub-logo-wrapper .activitypub-logo {
		box-shadow: var(--boxshadow);
		border-radius: var(--br);	
		max-width: 100%;
}

