/*
  theme-title: Blurple (dark)
  theme-description: Official dark blurple theme
*/

/* Use dark code highlights. */
@import url("../dist/_prism-dark.css");

:root {
  /* Define our nice blurple palette */
  --blurple1: #ebe6f8;
  --blurple2: #d6cceb;
  --blurple3: #c2b3e1;
  --blurple4: #aa60ff;
  --blurple5: #783d9f;
  --blurple6: #2d2b55;
  --blurple7: #1f1f41;

  /* Override orange trim */
  --orange2: #fad000;

  /* Restyle basic colors to use blurple */
  --blue1: var(--blurple1);
  --blue2: var(--blurple2);
  --blue3: var(--blurple3);

  /* Basic page styling (background + foreground) */
  --bg: var(--blurple7);
  --bg-accent: var(--blurple6);
  --fg: var(--blurple1);
  --fg-reduced: var(--blurple2);

  /* Profile page styling */
  --profile-bg: var(--blurple6);

  /* Blurpleize buttons */
  --button-bg: var(--blurple2);
  --button-fg: var(--blurple5);

  /* Blurpleize statuses */
  --status-bg: var(--blurple6);
  --status-focus-bg: var(--blurple6);
  --status-info-bg: var(--blurple5);
  --status-focus-info-bg: var(--blurple5);

  /* Used around statuses + other items */
  --boxshadow-border: 0.08rem solid black;
}

/* Main page background */
body {
  background: linear-gradient(var(--blurple7), black);
}

/* Scroll bar */
html, body {
  scrollbar-color: var(--blurple4) var(--blurple7);
}

/* Profile fields */
.profile .about-user .fields .field {
  border-bottom: 0.1rem solid var(--blurple4);
}
.profile .about-user .fields .field:first-child {
  border-top: 0.1rem solid var(--blurple4);
}

/* Status media */
.status .media .media-wrapper {
  border: 0.08rem solid var(--blurple5);
}
.status .media .media-wrapper details .unknown-attachment .placeholder {
  color: var(--blue2);
}
.status .media .media-wrapper details video.plyr-video {
  background: var(--blurple6);
}

/* Status polls */
.status .text .poll {
  background-color: var(--bg);
}
.status .text .poll .poll-info {
  background-color: var(--blurple6);
}

/* Code snippets */
pre, pre[class*="language-"],
code, code[class*="language-"] {
	background-color: var(--blurple7);
  color: var(--fg-reduced);
}

/* Block quotes */
blockquote {
  background-color: var(--blurple7);
  color: var(--fg-reduced);
}
