
/*
	GoToSocial
	Copyright (C) GoToSocial Authors admin@gotosocial.org
	SPDX-License-Identifier: AGPL-3.0-or-later

	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU Affero General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU Affero General Public License for more details.

	You should have received a copy of the GNU Affero General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

.thread,
.thread-wrapper {
	display: flex;
	flex-direction: column;
	gap: 0.4rem;
}

.thread .col-header {
		box-shadow: var(--boxshadow);
		border: var(--boxshadow-border);
	}

.thread .col-header.replies.hidden-only {
			/*
				No visible replies below this column
				header, so round off the bottom.
			*/
			border-bottom-left-radius: var(--br);
			border-bottom-right-radius: var(--br);
		}

.thread .col-header div#thread-show-hide-all-toggle-wrapper > button {
			/* Sized specifically to avoid making the col-header taller */
			font-size: 1rem;
			padding: 0.175rem 0.3rem;
		}

.thread .status.indent-1 {
			margin-left: 0.5rem;
		}

.thread .status.indent-2 {
			margin-left: 1rem;
		}

.thread .status.indent-3 {
			margin-left: 1.5rem;
		}

.thread .status.indent-4 {
			margin-left: 2rem;
		}

.thread .status.indent-5 {
			margin-left: 2.5rem;
		}

/*
				Show a stripey line to the left of
				indented statuses for better legibility.
			*/

.thread .status.indent-1::before, .thread .status.indent-2::before, .thread .status.indent-3::before, .thread .status.indent-4::before, .thread .status.indent-5::before {
				content: "";
				position: absolute;
				left: 0;
				top: 0;
				height: 100%;
				border-left: 0.15rem dashed var(--border-accent);
				margin-left: -0.5rem;
			}

.thread .status {

		border-radius: 0;
}

.thread .status:last-child {
			border-bottom-left-radius: var(--br);
			border-bottom-right-radius: var(--br);
		}

.thread .status:last-child .status-info {
				border-bottom-left-radius: var(--br);
				border-bottom-right-radius: var(--br);
			}


